=============================
mptt-tree-view
=============================

.. image:: https://badge.fury.io/py/mptt-tree-view.png
    :target: https://badge.fury.io/py/mptt-tree-view

.. image:: https://travis-ci.org/weijia/mptt-tree-view.png?branch=master
    :target: https://travis-ci.org/weijia/mptt-tree-view

"View tool for Django MPTT"

Documentation
-------------

The full documentation is at https://mptt-tree-view.readthedocs.org.

Quickstart
----------

Install mptt-tree-view::

    pip install mptt-tree-view

Then use it in a project::

    import mptt_tree_view

Features
--------

* TODO

Running Tests
--------------

Does the code actually work?

::

    source <YOURVIRTUALENV>/bin/activate
    (myenv) $ pip install -r requirements-test.txt
    (myenv) $ python runtests.py

Credits
---------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-pypackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-djangopackage`: https://github.com/pydanny/cookiecutter-djangopackage
